Index: src/x64/lithium-codegen-x64.cc |
diff --git a/src/x64/lithium-codegen-x64.cc b/src/x64/lithium-codegen-x64.cc |
index d8e392147684ec6e2ab4054a624bba899e92f28b..029070a729f61920f3e3f53db5c5a3f28d2f45eb 100644 |
--- a/src/x64/lithium-codegen-x64.cc |
+++ b/src/x64/lithium-codegen-x64.cc |
@@ -2276,8 +2276,8 @@ void LCodeGen::DoCompareNumericAndBranch(LCompareNumericAndBranch* instr) { |
} else { |
__ cmpl(ToOperand(right), Immediate(value)); |
} |
- // We transposed the operands. Reverse the condition. |
- cc = ReverseCondition(cc); |
+ // We commuted the operands, so commute the condition. |
+ cc = CommuteCondition(cc); |
} else if (instr->hydrogen_value()->representation().IsSmi()) { |
if (right->IsRegister()) { |
__ cmpp(ToRegister(left), ToRegister(right)); |
@@ -4118,7 +4118,7 @@ void LCodeGen::DoBoundsCheck(LBoundsCheck* instr) { |
} else { |
__ cmpl(index, Immediate(length)); |
} |
- cc = ReverseCondition(cc); |
+ cc = CommuteCondition(cc); |
} else if (instr->index()->IsConstantOperand()) { |
int32_t index = ToInteger32(LConstantOperand::cast(instr->index())); |
if (instr->length()->IsRegister()) { |